//! Commands contains the command constants expected during the UCI lifecycle
//! It is useful to note many of these commands do not end with '\n'. This is because they expect arguments.


///////// Engine to GUI /////////


/// ID is used to signal the engine name and author to the GUI
pub const ID: &'static str = "id";

/// NAME is used to signal the engine name
pub const NAME: &'static str = "name";

/// AUTHOR is used to signal the engine author
pub const AUTHOR: &'static str = "author";

/// UCIOK is sent after the ID and optional options to tell the GUI that the engine has sent all infos and is ready
/// in UCI mode
pub const UCIOK: &'static str = "uciok\n";

/// READYOK is sent when the engine has received an "isready" command and has processed all input and is ready to
/// accept new commands now
pub const READYOK: &'static str = "readyok\n";

/// BESTMOVE is sent when the engine has stopped searching and found the move best in this position
pub const BESTMOVE: &'static str = "bestmove";

/// COPYPROTECTIONCHECKING tells the GUI that the engine is checking the copy protection
pub const COPYPROTECTIONCHECKING: &'static str = "copyprotection checking\n";

/// COPYPROTECTIONOK tells the GUI that the engine has verified the copy protection
pub const COPYPROTECTIONOK: &'static str = "copyprotection ok\n";

/// COPYPROTECTIONERROR tells the GUI that the engine has rejected the copy protection
pub const COPYPROTECTIONERROR: &'static str = "copyprotection error\n";

/// REGISTRATIONCHECKING tells the GUI that the engine is checking the registration
pub const REGISTRATIONCHECKING: &'static str = "registration checking\n";

/// REGISTRATIONOK tells the GUI that the engine the registration has been verified
pub const REGISTRATIONOK: &'static str = "registration ok\n";

/// REGISTRATIONERROR tells the GUI that the engine has rejected the registration
pub const REGISTRATIONERROR: &'static str = "registration error\n";

/// INFO tells the GUI the engine wants to sent infos to the GUI. This should be done whenever the info has changed
pub const INFO: &'static str = "info";

/// OPTION tells the GUI which parameters can be changed in the engine
pub const OPTION: &'static str = "option";

/// OPTIONNAME tells the GUI which option name is being sent
pub const OPTIONNAME: &'static str = "name";

/// TYPE tells the GUI the type of the option
pub const TYPE: &'static str = "type";

